@@ -376,6 +376,8 @@ class BeamtimeLoader(object):
         "endTime": "scientificMetadata.end_time.value",
         "creationTime": "scientificMetadata.end_time.value",
         "description": "scientificMetadata.title.value",
+        "scientificMetadata.ScanCommand":
+            "scientificMetadata.program_name.scan_command",
     }
 
     def __init__(self, options):
@@ -489,38 +491,125 @@ class BeamtimeLoader(object):
             return metadata
         return dict(self._mergedict(metadata, self.__metadata))
 
-    def overwrite(self, metadata, cmap=None):
+    def merge_copy_maps(self, cmap):
+        """ merge copy maps
+
+        :param cmap: overwrite dictionary
+        :type cmap: :obj:`dict` <:obj:`str`, :obj:`str`>
+        :param cmapfield: copy map nexus field
+        :type cmapfield: :obj:`str`
+        :returns: metadata dictionary
+        :rtype: :obj:`dict` <:obj:`str`, `any`>
+        """
+        if cmap is None:
+            cpmap = dict(self.copymap)
+        else:
+            cpmap = dict(self.copymap)
+            cpmap.update(cmap)
+        return cpmap
+
+    def append_copymap_field(self, metadata, cmap, cmapfield=None):
         """ overwrite metadata with dictionary
 
         :param metadata: metadata dictionary to merge in
         :type metadata: :obj:`dict` <:obj:`str`, `any`>
         :param cmap: overwrite dictionary
         :type cmap: :obj:`dict` <:obj:`str`, :obj:`str`>
+        :param cmapfield: copy map nexus field
+        :type cmapfield: :obj:`str`
         :returns: metadata dictionary
         :rtype: :obj:`dict` <:obj:`str`, `any`>
         """
-        if cmap is None:
-            cmap = self.copymap
-        if metadata:
-            for ts, vs in self.copymap.items():
-                vls = vs.split(".")
-                md = metadata
-                for vl in vls:
-                    if vl in md:
-                        md = md[vl]
-                    else:
-                        break
+        if cmapfield and metadata and cmap:
+            vls = cmapfield.split(".")
+            md = metadata
+            for vl in vls:
+                if vl in md:
+                    md = md[vl]
                 else:
-                    tgs = ts.split(".")
-                    td = metadata
-                    parent = None
-                    for tg in tgs:
-                        parent = td
-                        if tg in td:
-                            td = td[tg]
+                    break
+            else:
+                if md:
+                    try:
+                        dct = yaml.safe_load(str(md).strip())
+                        if dct and isinstance(dct, dict):
+                            cmap.update(dct)
+                    except Exception as e:
+                        sys.stderr.write(
+                            "nxsfileinfo: copymap update: '%s'\n"
+                            % str(e))
+
+    def overwrite(self, metadata, cmap=None, cmapfield=None):
+        """ overwrite metadata with dictionary
+
+        :param metadata: metadata dictionary to merge in
+        :type metadata: :obj:`dict` <:obj:`str`, `any`>
+        :param cmap: overwrite dictionary
+        :type cmap: :obj:`dict` <:obj:`str`, :obj:`str`>
+        :param cmapfield: copy map nexus field
+        :type cmapfield: :obj:`str`
+        :returns: metadata dictionary
+        :rtype: :obj:`dict` <:obj:`str`, `any`>
+        """
+        cpmap = self.merge_copy_maps(cmap)
+        self.append_copymap_field(metadata, cpmap, cmapfield)
+        if metadata:
+            for ts, vs in cpmap.items():
+                if ts and vs:
+                    vls = vs.split(".")
+                    md = metadata
+                    for vl in vls:
+                        if vl in md:
+                            md = md[vl]
                         else:
-                            td = td[tg] = {}
-                    parent[tg] = md
+                            break
+                    else:
+                        tgs = ts.split(".")
+                        td = metadata
+                        parent = None
+                        for tg in tgs:
+                            parent = td
+                            if tg in td:
+                                td = td[tg]
+                            else:
+                                td = td[tg] = {}
+                        parent[tg] = md
+        return metadata
+
+    def remove_metadata(self, metadata, cmap=None, cmapfield=None):
+        """ remove metadata with dictionary with empty input or output
+            in the copy map
+
+        :param metadata: metadata dictionary to merge in
+        :type metadata: :obj:`dict` <:obj:`str`, `any`>
+        :param cmap: overwrite dictionary
+        :type cmap: :obj:`dict` <:obj:`str`, :obj:`str`>
+        :param cmapfield: copy map nexus field
+        :type cmapfield: :obj:`str`
+        :returns: metadata dictionary
+        :rtype: :obj:`dict` <:obj:`str`, `any`>
+        """
+        cpmap = self.merge_copy_maps(cmap)
+        self.append_copymap_field(metadata, cpmap, cmapfield)
+        if metadata:
+            for ts, vs in cpmap.items():
+                vv = None
+                if not ts:
+                    vv = vs
+                if not vs:
+                    vv = ts
+                if vv:
+                    vls = vv.split(".")
+                    md = metadata
+                    parent = None
+                    for vl in vls:
+                        parent = md
+                        if vl in md:
+                            md = md[vl]
+                        else:
+                            break
+                    else:
+                        parent.pop(vl)
         return metadata
 
     @classmethod
@@ -805,6 +894,10 @@ class Metadata(Runner):
             "-m", "--raw-metadata", action="store_true",
             default=False, dest="rawscientific",
             help="do not store NXentry as scientificMetadata")
+        self._parser.add_argument(
+            "--add-empty-units", action="store_true",
+            default=False, dest="emptyunits",
+            help="add empty units for fields without units")
         self._parser.add_argument(
             "--oned", action="store_true",
             default=False, dest="oned",
@@ -838,6 +931,17 @@ class Metadata(Runner):
         self._parser.add_argument(
             "-x", "--chmod", dest="chmod",
             help=("json metadata file mod bits, e.g. 0o662"))
+        self._parser.add_argument(
+            "--copy-map", dest="copymap",
+            help=("json or yaml map {output: input} to re-arrange metadata"))
+        self._parser.add_argument(
+            "--copy-map-field", dest="copymapfield",
+            help=(
+                "field json or yaml with map {output: input} "
+                "to re-arrange metadata:"
+                "The default: "
+                "'scientificMetadata.nxsfileinfo_parameters.copymap.value'"),
+            default='scientificMetadata.nxsfileinfo_parameters.copymap.value')
 
     def postauto(self):
         """ parser creator after autocomplete run """
@@ -847,6 +951,10 @@ class Metadata(Runner):
         self._parser.add_argument(
             "-s", "--scientific-meta", dest="scientificmeta",
             help=("scientific metadata file"))
+        self._parser.add_argument(
+            "--copy-map-file", dest="copymapfile",
+            help=("json or yaml file containing the copy map, "
+                  "see also --copy-map"))
         self._parser.add_argument(
             "-o", "--output", dest="output",
             help=("output scicat metadata file"))
@@ -914,6 +1022,7 @@ class Metadata(Runner):
         attrs = None
         entryclasses = []
         entrynames = []
+        usercopymap = {}
 
         if options.values:
             values = options.values.split(',')
@@ -934,6 +1043,28 @@ class Metadata(Runner):
         if options.entrynames not in [None, '', "''", '""']:
             entrynames = options.entrynames.split(',')
 
+        copymapfield = None
+        if hasattr(options, "copymapfield") and options.copymapfield:
+            copymapfield = options.copymapfield
+
+        if hasattr(options, "copymap") and options.copymap:
+            dct = yaml.safe_load(options.copymap.strip())
+            if dct and isinstance(dct, dict):
+                usercopymap.update(dct)
+
+        if hasattr(options, "copymapfile") and options.copymapfile:
+            with open(options.copymapfile, "r") as fl:
+                jstr = fl.read()
+                # print(jstr)
+                try:
+                    dct = yaml.safe_load(jstr.strip())
+                except Exception:
+                    if jstr:
+                        nan = float('nan')    # noqa: F841
+                        dct = eval(jstr.strip())
+                        # mdflatten(dstr, [], dct)
+                if dct and isinstance(dct, dict):
+                    usercopymap.update(dct)
         result = None
         nxsparser = None
         if root is not None:
@@ -943,6 +1074,8 @@ class Metadata(Runner):
             nxsparser.entryclasses = entryclasses
             nxsparser.entrynames = entrynames
             nxsparser.scientific = not options.rawscientific
+            if hasattr(options, "emptyunits"):
+                nxsparser.emptyunits = options.emptyunits
             nxsparser.attrs = attrs
             nxsparser.hiddenattrs = nattrs
             if hasattr(options, "oned"):
@@ -952,7 +1085,8 @@ class Metadata(Runner):
         if nxsparser is None:
             bl = BeamtimeLoader(options)
             result = bl.run()
-            result = bl.overwrite(result)
+            result = bl.overwrite(
+                result, usercopymap or None, copymapfield)
             result = bl.update_pid(
                 result, None, options.puuid,
                 options.pfname, options.beamtimeid)
@@ -961,6 +1095,8 @@ class Metadata(Runner):
                 if hasattr(options, "techniques"):
                     techniques = options.techniques
                 result = bl.update_techniques(result, techniques)
+            result = bl.remove_metadata(
+                result, usercopymap or None, copymapfield)
         elif nxsparser and nxsparser.description:
             if len(nxsparser.description) == 1:
                 desc = nxsparser.description[0]
@@ -981,7 +1117,8 @@ class Metadata(Runner):
                 bl = BeamtimeLoader(options)
                 bl.run()
                 result = bl.merge(desc)
-                result = bl.overwrite(result)
+                result = bl.overwrite(
+                    result, usercopymap or None, copymapfield)
                 result = bl.update_pid(
                     result, options.args[0], options.puuid,
                     options.pfname, options.beamtimeid)
@@ -991,6 +1128,8 @@ class Metadata(Runner):
                         techniques = options.techniques
                     result = bl.update_techniques(result, techniques)
 
+                result = bl.remove_metadata(
+                    result, usercopymap or None, copymapfield)
             else:
                 result = []
                 for desc in nxsparser.description:
@@ -1011,7 +1150,8 @@ class Metadata(Runner):
                     bl = BeamtimeLoader(options)
                     bl.run()
                     rst = bl.merge(desc)
-                    rst = bl.overwrite(rst)
+                    rst = bl.overwrite(
+                        rst, usercopymap or None, copymapfield)
                     rst = bl.update_pid(
                         rst, options.args[0], options.puuid,
                         options.pfname, options.beamtimeid)
@@ -1020,6 +1160,8 @@ class Metadata(Runner):
                         if hasattr(options, "techniques"):
                             techniques = options.techniques
                         rst = bl.update_techniques(rst, techniques)
+                    rst = bl.remove_metadata(
+                        rst, usercopymap or None, copymapfield)
                     result.append(rst)
         if result is not None:
             return json.dumps(
