@@ -151,6 +151,8 @@ class NXSFileParser(object):
         self.group_postfix = ""
         #: (:obj:`bool`) store NXentries as scientificMetadata
         self.scientific = False
+        #: (:obj:`bool`) add empty units
+        self.emptyunits = False
         #: (:obj:`dict` <:obj:`str`, `any`>)  metadata dictionary
         self.__dctmetadata = {}
 
@@ -452,7 +454,9 @@ class NXSFileParser(object):
                        (self.hiddenattrs is None or
                             at not in self.hiddenattrs):
                         nd[at] = filewriter.first(attrs[at].read())
-
+            if self.scientific and "NX_class" in nd.keys() and \
+               nd["NX_class"] == "NXentry":
+                nd.pop("NX_class")
         if not isinstance(node, filewriter.FTGroup):
             if (node.name in self.valuestostore and node.is_valid) \
                or "shape" not in desc \
@@ -477,6 +481,8 @@ class NXSFileParser(object):
                             except Exception:
                                 cont = False
                         nd["value"] = vl
+                        if self.emptyunits and "unit" not in nd.keys():
+                            nd["unit"] = ""
                     except Exception:
                         pass
             if "shape" in desc and desc["shape"] not in [None, [1], []]:
