@@ -188,6 +188,20 @@ standardComponentVariables = {
             'doc': "detector group name (string)"
         },
     },
+    'coboldhisto': {
+        'histogram': {
+            'default': None,
+            'doc': "histogram data (datasource)"
+        },
+        'binsize': {
+            'default': None,
+            'doc': "bin size of histogram data (datasource)"
+        },
+        'exposuretime': {
+            'default': None,
+            'doc': "exposure time for histogram data (datasource)"
+        },
+    },
     'maiaflux': {
         'detname': {
             'default': "maia",
@@ -819,6 +833,16 @@ standardComponentVariables = {
             "If it is  not set it is not created (string)"
         },
     },
+    'tango': {
+        'device': {
+            'default': None,
+            'doc': "tango device MANDATORY (string)"
+        },
+        'attribute': {
+            'default': 'Position',
+            'doc': "tango device attribute (string)"
+        },
+    },
     'starttime': {
     },
     'beamtimeid': {
@@ -926,11 +950,43 @@ standardComponentVariables = {
     'datasignal': {
         'signal': {
             'default': 'defaultsignal',
-            'doc': "data signal field name (string)"
+            'doc': "data signal field name (datasource)"
         },
         'axes': {
             'default': None,
-            'doc': "data axes field name(s) (string)"
+            'doc': "data axes field name(s) (datasource)"
+        },
+        'nchannelstoskip': {
+            'default': '0',
+            'doc': "number of mg channels to skip (string)"
+        },
+    },
+    'parametercopymap': {
+        'program': {
+            'default': 'nxsfileinfo_parameters',
+            'doc': "group name of NXparameters (string)"
+        },
+        'parameter': {
+            'default': 'copymap',
+            'doc': "parameter name of copymap (string)"
+        },
+        'copymap': {
+            'default': None,
+            'doc': "yaml dictionary with {output: input} copy map (string)"
+        },
+    },
+    'dataaxessignal': {
+        'signal': {
+            'default': 'defaultsignal',
+            'doc': "data signal field name (datasource)"
+        },
+        'axes': {
+            'default': 'defaultaxes',
+            'doc': "list of data axes field names (datasource)"
+        },
+        'nchannelstoskip': {
+            'default': '0',
+            'doc': "number of mg channels to skip (string)"
         },
     },
     'descriptiontext': {
@@ -1403,6 +1459,9 @@ standardComponentTemplateFiles = {
         'qbpm_foil.ds.xml',
         'qbpm.xml',
     ],
+    'parametercopymap': [
+        'parametercopymap.xml',
+    ],
     'secop': [
         'secop.ds.xml',
         'secop_time.ds.xml',
@@ -1470,6 +1529,13 @@ standardComponentTemplateFiles = {
         'signalname.ds.xml',
         'signal_axes.ds.xml',
     ],
+    'dataaxessignal': [
+        'dataaxessignal.xml',
+        'defaultsignal.ds.xml',
+        'defaultaxes.ds.xml',
+        'signal_name.ds.xml',
+        'signalname.ds.xml',
+    ],
     'defaultinstrument': [
         'defaultinstrument.xml',
         'beamtime_id.ds.xml',
@@ -1522,6 +1588,9 @@ standardComponentTemplateFiles = {
     'common2': [
         'common2_common.ds.xml',
     ],
+    'tango': [
+        'tango.ds.xml',
+    ],
     'common3': [
         'common3_common.ds.xml',
     ],
@@ -1556,12 +1625,18 @@ standardComponentTemplateFiles = {
     'pointdet': [
         'pointdet.xml',
     ],
+    'coboldhisto': [
+        'coboldhisto.xml',
+        'coboldhisto_timeofflight.ds.xml',
+    ],
+
 }
 
 #: (:obj:`dict` <:obj:`str` , :obj:`list` <:obj:`str`> >)
 #:     xml template files of modules
 moduleTemplateFiles = {
     'mythen2': ['mythen2.xml'],
+    'cobold': ['cobold.xml'],
     'mythen': ['mythen.xml',
                'mythen_postrun.ds.xml',
                'mythen_filestartnumber.ds.xml'],
@@ -1876,6 +1951,9 @@ moduleMultiAttributes = {
         'Energy', 'NbFrames', 'RoI1End', 'RoI2End', 'RoI1Start', 'RoI2Start',
         'Threshold'
     ],
+    'cobold': [
+        'BinSize', 'ExposureTime'
+    ],
     'marccd': [
         'FrameShift', 'SavingDirectory', 'SavingPostfix', 'SavingPrefix'],
     'eigerdectris': [
