@@ -27,7 +27,10 @@ import struct
 import binascii
 # import time
 # import threading
-import PyTango
+try:
+    import tango
+except Exception:
+    import PyTango as tango
 # import json
 from nxstools import nxscreate
 from nxstools.xmltemplates import standardComponentVariables
@@ -91,7 +94,7 @@ class NXSCreateStdCompFSTest(unittest.TestCase):
                       '"read_default_file":"/etc/my.cnf", "use_unicode":true}'
 
         # home = expanduser("~")
-        db = PyTango.Database()
+        db = tango.Database()
         self.host = db.get_db_host().split(".")[0]
         self.port = db.get_db_port()
         self._sv = ServerSetUp.ServerSetUp()
@@ -297,19 +300,20 @@ class NXSCreateStdCompFSTest(unittest.TestCase):
                 self.assertEqual(
                     lines[-2].split(),
                     ["absorber", "beamstop", "beamtimefname",
-                     "beamtimeid", "chcut",
+                     "beamtimeid", "chcut", "coboldhisto",
                      "collect2", "collect3",
                      "collect4", "collect5", "collect6",
                      "common2", "common3",
+                     "dataaxessignal",
                      "datasignal", "dcm", "default", "defaultinstrument",
                      "defaultsample", "description",
                      "descriptiontext", "detectorlive",
                      "empty", "groupsecop", "keithley", "maia",
                      "maiadimension", "maiaflux", "msnsar", "mssar",
-                     "pinhole",
+                     "parametercopymap", "pinhole",
                      "pointdet", "qbpm", "samplehkl", "secop",
                      "singlesecop", "slit", "source", "starttime",
-                     "undulator"])
+                     "tango", "undulator"])
                 self.assertEqual(lines[-1], "")
         finally:
             pass
@@ -321,17 +325,19 @@ class NXSCreateStdCompFSTest(unittest.TestCase):
         print("Run: %s.%s() " % (self.__class__.__name__, fun))
 
         types = ["absorber", "beamstop", "beamtimeid", "chcut",
-                 "collect2", "collect3",
+                 "coboldhisto", "collect2", "collect3",
                  "collect4", "collect5", "collect6",
                  "common2", "common3",
+                 "dataaxessignal",
                  "datasignal", "dcm", "default", "defaultinstrument",
                  "defaultsample", "description",
                  "descriptiontext", "detectorlive",
                  "empty", "groupsecop", "keithley", "maia",
-                 "maiadimension", "maiaflux", "pinhole",
+                 "maiadimension", "maiaflux",
+                 "parametercopymap", "pinhole",
                  "pointdet", "qbpm", "samplehkl",
                  "secop", "singlesecop", "slit",
-                 "source", "starttime", "undulator"]
+                 "source", "starttime", "tango", "undulator"]
         args = [
                 ('nxscreate stdcomp %s -t ' % self.flags).split(),
                 ('nxscreate stdcomp %s --type ' % self.flags).split(),
@@ -922,6 +928,11 @@ class NXSCreateStdCompFSTest(unittest.TestCase):
                      '    </group>\n'
                      '    <field name="program_name" '
                      'scan_command="$var.scan_title" scan_id="$var.scan_id" '
+                     'measurement_group="$var.measurement_group" '
+                     'measurement_group_channels="$var.mgchannels" '
+                     'nexus_components="$var.nexus_components" '
+                     'nexus_step_datasources="$var.nexus_step_datasources" '
+                     'nexus_init_datasources="$var.nexus_init_datasources" '
                      'type="NX_CHAR">NexDaTaS<attribute name="version" '
                      'type="NX_CHAR">\n'
                      '        <strategy mode="INIT" />'
@@ -979,7 +990,8 @@ class NXSCreateStdCompFSTest(unittest.TestCase):
                      '  <datasource name="nexdatas_version" type="PYEVAL">\n'
                      '    <result name="result">\n'
                      'from nxswriter import __version__\n'
-                     'ds.result = __version__</result>\n'
+                     'ds.result = __version__   # from nxswriter\n'
+                     '    </result>\n'
                      '  </datasource>\n'
                      '</definition>',
                      '<?xml version=\'1.0\' encoding=\'utf8\'?>\n'
@@ -1017,7 +1029,7 @@ class NXSCreateStdCompFSTest(unittest.TestCase):
                      '<definition>\n'
                      '  <datasource type="PYEVAL" name="beamtime_filename">\n'
                      '    <result name="result">\n'
-                     '    ds.result = ""</result>\n'
+                     'ds.result = ""\n</result>\n'
                      '  </datasource>\n'
                      '</definition>']
                 ],
@@ -1092,6 +1104,11 @@ class NXSCreateStdCompFSTest(unittest.TestCase):
                      '    </group>\n'
                      '    <field name="program_name" '
                      'scan_command="$var.scan_title" scan_id="$var.scan_id" '
+                     'measurement_group="$var.measurement_group" '
+                     'measurement_group_channels="$var.mgchannels" '
+                     'nexus_components="$var.nexus_components" '
+                     'nexus_step_datasources="$var.nexus_step_datasources" '
+                     'nexus_init_datasources="$var.nexus_init_datasources" '
                      'type="NX_CHAR">NexDaTaS<attribute name="version" '
                      'type="NX_CHAR">\n'
                      '        <strategy mode="INIT" />'
@@ -1149,7 +1166,8 @@ class NXSCreateStdCompFSTest(unittest.TestCase):
                      '  <datasource name="nexdatas_version" type="PYEVAL">\n'
                      '    <result name="result">\n'
                      'from nxswriter import __version__\n'
-                     'ds.result = __version__</result>\n'
+                     'ds.result = __version__   # from nxswriter\n'
+                     '    </result>\n'
                      '  </datasource>\n'
                      '</definition>',
                      '<?xml version=\'1.0\' encoding=\'utf8\'?>\n'
@@ -1187,7 +1205,7 @@ class NXSCreateStdCompFSTest(unittest.TestCase):
                      '<definition>\n'
                      '  <datasource type="PYEVAL" name="beamtime_filename">\n'
                      '    <result name="result">\n'
-                     '    ds.result = ""</result>\n'
+                     'ds.result = ""\n</result>\n'
                      '  </datasource>\n'
                      '</definition>']
                 ],
